@@ -7,9 +7,11 @@ from ..base_optimizer import BaseOptimizer
 
 
 class RandomSearch(BaseOptimizer):
-    def __init__(self, **optimizer_kwargs):
+    def __init__(self, use_priors=False, ignore_fidelity=True, **optimizer_kwargs):
         super().__init__(**optimizer_kwargs)
         self._num_previous_configs: int = 0
+        self.use_priors = use_priors
+        self.ignore_fidelity = ignore_fidelity
 
     def load_results(
         self,
@@ -20,7 +22,9 @@ class RandomSearch(BaseOptimizer):
 
     def get_config_and_ids(self) -> tuple[SearchSpace, str, str | None]:
         config = self.pipeline_space.sample(
-            patience=self.patience, user_priors=True, ignore_fidelity=False
+            patience=self.patience,
+            user_priors=self.use_priors,
+            ignore_fidelity=self.ignore_fidelity,
         )
         config_id = str(self._num_previous_configs + 1)
         return config.hp_values(), config_id, None
